@@ -7,16 +7,14 @@ class PackageInterface(object):
     @property
     @abc.abstractmethod
     def parent(self):
-        raise NotImplementedError(
-            'must define get_model_dim_arrays in child '
-            'class to use this base class')
+        raise NotImplementedError("must define get_model_dim_arrays in child "
+                                  "class to use this base class")
 
     @parent.setter
     @abc.abstractmethod
     def parent(self, name):
-        raise NotImplementedError(
-            'must define get_model_dim_arrays in child '
-            'class to use this base class')
+        raise NotImplementedError("must define get_model_dim_arrays in child "
+                                  "class to use this base class")
 
 
 class Package(PackageInterface):
